@@ -48,7 +48,7 @@ class NewsForm(BaseContentForm, RelateMixin, RichTextMixin):
                    # Translators: djinn_news documents link label
                    'label': _("Search documents"),
                    'searchfield': 'title_auto',
-                   'template_name': 'search/relate_search_widget.html',
+                   'template_name': 'djinn_forms/snippets/relatesearchwidget.html',
                    'search_url': '/zoeken/zoekajaxlinkdocument/',
                    'ct_searchfield': 'meta_type', },
             # TODO:reverse('haystack_link_popup') is mooier
